import {
    Component,
    View,
    Input,
    Output,
    EventEmitter,

    CORE_DIRECTIVES
} from 'angular2/angular2';

@Component({
    selector: 'modal',
    directives: [
        CORE_DIRECTIVES
    ],
    template: `
        <div [ng-class]="{ 'modal': true, 'fade': true, 'in': isopened, 'opened': isopened }" role="dialog">
            <div class="modal-dialog" role="document">
                <div class="modal-content">
                    <ng-content></ng-content>
                </div>
                <!-- /.modal-content -->
            </div>
            <!-- /.modal-dialog -->
        </div>
        <!-- /.modal -->
    `
})
export class Modal {
    @Input() isopened : boolean;

    @Output() close: EventEmitter<string>;

    constructor() {
        this.close = new EventEmitter();
    }
}

@Component({
    selector: 'modal-header',
    template: `
        <div class="modal-header">
            <button type="button" class="close" (click)="sendClose()"><span aria-hidden="true">&times;</span></button>
            <h4 class="modal-title">
                <ng-content></ng-content>
            </h4>
        </div>
        <!-- /.modal-header -->
    `
})
export class ModalHeader {

}

@Component({
    selector: 'modal-body',
    template: `
        <div class="modal-body">
            <ng-content></ng-content>
        </div>
        <!-- /.modal-body -->
    `
})
export class ModalBody {

}

@Component({
    selector: 'modal-footer',
    template: `
        <div class="modal-footer">
            <ng-content></ng-content>
        </div>
        <!-- /.modal-footer -->
    `
})
export class ModalFooter {

}

export const MODAL_DIRECTIVES = [
    Modal,
    ModalHeader,
    ModalBody,
    ModalFooter
];